OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Kaset eo bet ar restr",
    "No file was uploaded" : "N'eus restr ebet a zo bet kaset",
    "File not found" : "Restr ebet kavet",
    "Text" : "Testenn",
    "Reload" : "Adkargañ",
    "Guest" : "Kouviad",
    "edit" : "embann",
    "Copy link" : "Eilañ al liamm",
    "guest" : "kouviad",
    "Offline" : "Distaget",
    "Saving …" : "Orc'h enrolliñ",
    "Saved" : "Enrollet",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Cheñchet eo bet an diel er maez eus an embanner. N'eo ket posuple lakaat pez a oa bet cheñchet.",
    "Unsaved changes" : "Kemmoù n'int ket bet enrollet",
    "Save changes" : "Enrollañ ar cheñchamantoù",
    "Cancel" : "Nullañ",
    "URL" : "URL",
    "Translate" : "Treiñ",
    "Translate to" : "Treiñ e",
    "Replace" : "Erlec'hiañ",
    "Upload" : "Enporzhiañ",
    "Edit" : "Cheñch",
    "Done" : "Graet",
    "Details" : "Munudoù",
    "Command" : "Urzh",
    "Choose" : "Dibab",
    "Add folder description" : "Ouzhpennañ un deskrivadur evit ar renkell",
    "Edit guest name" : "Embannañ anv an hini pedet",
    "Save guest name" : "Enrollañ anv an hini pedet"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
